import java.util.Vector;
import java.util.Iterator;

/**
 * The group node for building the hierarchy in the scene graph.
 * <p>
 * Group nodes, or their subclasses, are the only non-leaf nodes in the scene graph.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglGroup extends jooglNode {
    /** The children of the group node. */
    protected Vector children;
    
    /** Create a new group node with no children */
    public jooglGroup() 
    {
        super();
        children = new Vector();
    }

    // methods to manipulate the collection of children.  These are analogous to the Collection methods.
    /** Add a child to the group.  Analogous to the Collection method. */
    public boolean add(jooglNode n) 
    {
        redrawWindows();
        return children.add(n);
    }
    
    /** Add all the children from one group to another group.  Analogous to the Collection method. */
    public boolean addAll(jooglGroup g)
    {
        redrawWindows();
        return children.addAll(g.children);
    }
    
    /** Remove all the children from the group.  Analogous to the Collection method. */
    public void clear()
    {
        redrawWindows();
        children.clear();
    }
    
    /** Is a child in the group?  Analogous to the Collection method. */
    public boolean contains(jooglNode n)
    {
        return children.contains(n);
    }
    
    /** Are all the children in another group in this group?  Analogous to the Collection method. */
    public boolean containsAll(jooglGroup g)
    {
        return children.containsAll(g.children);
    }
    
    /** Is this group empty?  Analogous to the Collection method. */
    public boolean isEmpty()
    {
        return children.isEmpty();
    }
    
    /** Create an iterator to iterate through the children of the group.  Analogous to the Collection method. */
    public Iterator iterator() 
    {
        return children.iterator();
    }
    
    /** Remove a child from the group.  Analogous to the Collection method. */
    public boolean remove(jooglNode n) 
    {
        redrawWindows();
        return children.remove(n);
    }
    
    /** Remove all the children in a group from this group.  Analogous to the Collection method. */
    public boolean removeAll(jooglGroup g) 
    {
        redrawWindows();
        return children.removeAll(g.children);
    }

    /** Remove all the children from this group that are not in the specified group.  Analogous to the Collection method. */
    public boolean retainAll(jooglGroup g) 
    {
        redrawWindows();
        return children.retainAll(g.children);
    }
    
    /** How many children are in the group?  Analogous to the Collection method. */
    public int size() 
    {
        return children.size();
    }
}
