/**
 * The geometry node for a sphere.
 *
 * @version 	1.00
 * @author      Blair MacIntyre
 */
public class jooglSphere extends jooglGeometry{
    /** The size of the cube. */
    protected double size;
    /** The precision of the cube. */
    protected int precision;
    
    /** The default constructor. */
    public jooglSphere ()
    {
        super();
        size = 1.0;
        precision = 30;
    }

    /** A constructor where the size and precision are specified. 
     *
     * @param _size the radius of the sphere.
     * @param _precision the precision, or number of subdivisions in each direction
     */
    public jooglSphere (double _size, int _precision)
    {
        super();
        size = _size;
        precision = _precision;
    }
    
    /**
     * Set the size of the sphere.
     * 
     * @param _size the new size of the sphere.
     */
    public void setSize(double _size)
    {
        size = _size;
        redrawWindows();
    }

    /**
     * Get the size of the sphere.
     * 
     * @return the current size of the sphere.
     */
    public double getSize()
    {
        return size;
    }

    /**
     * Set the precision of the sphere.
     * 
     * @param p the new precision of the sphere.
     */
    public void setPrecision(int p)
    {
        precision = p;
        redrawWindows();
    }

    /**
     * Get the precision of the sphere.
     * 
     * @return the current precision of the sphere.
     */
    public int getPrecision()
    {
        return precision;
    }
    
    /** Internal function, to recreate the sphere display list */
    protected void recreateDisplayList()
    {	
	gl.glNewList(dl, GL_COMPILE);
	glut.glutSolidSphere(size, precision, precision);
	gl.glEndList();
    }
}
